fn property
The side effect function to execute.
This function is called whenever any of the effect's dependencies change.
Implementation
final EffectCallback<T> fn;
The side effect function to execute.
This function is called whenever any of the effect's dependencies change.
final EffectCallback<T> fn;