EffectScopeNode class

A reactive effect scope node that can participate in propagation.

Inheritance

Constructors

EffectScopeNode({required ReactiveFlags flags})

Properties

deps Link?
Head of the linked list of dependencies (nodes this node depends on). Null if this node has no dependencies.
getter/setter pairinherited
depsTail Link?
Tail of the linked list of dependencies for O(1) append operations. Points to the last dependency link.
getter/setter pairinherited
flags ReactiveFlags
Bit flags representing the current state of this node. See ReactiveFlags for possible values.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subs Link?
Head of the linked list of subscribers (nodes that depend on this node). Null if no other nodes depend on this one.
getter/setter pairinherited
subsTail Link?
Tail of the linked list of subscribers for O(1) append operations. Points to the last subscriber link.
getter/setter pairinherited

Methods

didUpdate() bool
Marks the scope as mutable while dirty checking propagates through it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited