stopEffect function
Stops an effect after disposing its nested effects and scopes.
Implementation
void stopEffect(EffectNode e) {
stopScope(e);
if (e.cleanup != null) {
runCleanup(e);
}
}
Stops an effect after disposing its nested effects and scopes.
void stopEffect(EffectNode e) {
stopScope(e);
if (e.cleanup != null) {
runCleanup(e);
}
}